@@ -41,12 +41,12 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_lambda
-import constructs
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_5443dbc3
+import constructs as _constructs_77d1e7e8
 
 
 class KubectlLayer(
-    aws_cdk.aws_lambda.LayerVersion,
+    _aws_cdk_aws_lambda_5443dbc3.LayerVersion,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/lambda-layer-kubectl.KubectlLayer",
 ):
@@ -64,15 +64,13 @@ class KubectlLayer(
         fn.add_layers(KubectlLayer(self, "KubectlLayer"))
     '''
 
-    def __init__(self, scope: constructs.Construct, id: builtins.str) -> None:
+    def __init__(self, scope: _constructs_77d1e7e8.Construct, id: builtins.str) -> None:
         '''
         :param scope: -
         :param id: -
         '''
         if __debug__:
-            def stub(scope: constructs.Construct, id: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__3d29e04d890187ad55d8cc0954ff1b96a1fea49f83759e8b912bac3e69a99457)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         jsii.create(self.__class__, self, [scope, id])
@@ -83,3 +81,10 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__3d29e04d890187ad55d8cc0954ff1b96a1fea49f83759e8b912bac3e69a99457(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
